/*
 * @Description: 包装规则相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-07-06 23:26:47
 */

import { ActionItem, BasicColumn } from '/@/components/Table';
import { isNullOrUnDef } from '/@/utils/is';
import { buildUUID } from '/@/utils/uuid';

function _default() {
  const ActionColumn: BasicColumn = {
    width: 80,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: undefined,
  };

  /**
   * @description: 一些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (fnName: string) => {
      return {
        action: 'go', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
        url: 'BAS_PKG_DTL/High',
        params: {
          CODE: '0',
          ID: buildUUID(),
          Name: 'BAS_PKG_DTL',
          Title: '新增包装规则',
          IsExist: 'RULE_CODE',
          IsID: true,
          drawers: [
            {
              name: 'BAS_PKG_DTL', //实际的实体名
              dataType: 'V_BAS_PKG_DTL', //如果这里给了值，则会替换name的实体名去查义数据库
              code: 'PKG_RULE_ID',
              type: 'one',
              keyName: 'BAS_PKG_DTL',
              order: 'PKG_LEVEL',
            },
          ], //drawers是右边弹出增改侧框的名字列表
        },
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      if (!isNullOrUnDef(data[0])) {
        data[0].onClick = pkgGrpEdit.bind(null, args[5], params);
      }
      return data;
    },
  };

  /* 以下是内部方法，不export，供上面的方法调用 */

  /**
   * @description: 自定义编辑方法，跳转到高级页面
   * @param {Fn} args
   * @param {*} params
   * @return {*}
   */
  function pkgGrpEdit(go: Fn, params: {}) {
    const param = {
      CODE: params['record']['RULE_CODE'],
      ID: params['record']['ID'],
      Name: 'BAS_PKG_DTL',
      SessionName: 'BAS_PKG_DTL_update',
      Title: `编辑包装规则：${params['record']['RULE_CODE']}`,
      IsExist: 'RULE_CODE',
      IsID: true,
      drawers: [
        {
          name: 'BAS_PKG_DTL',
          dataType: 'V_BAS_PKG_DTL', //如果这里给了值，则会替换name的实体名去查义数据库
          code: 'PKG_RULE_ID',
          type: 'one',
          keyName: 'BAS_PKG_DTL',
          order: 'PKG_LEVEL',
        },
      ], //drawers是右边弹出增改侧框的名字列表
    };
    // 将对象转换为JSON字符串并保存到sessionStorage
    sessionStorage.removeItem(`${param.SessionName}_params`);
    sessionStorage.setItem(`${param.SessionName}_params`, encodeURI(JSON.stringify(param)));
    go(
      `/BAS_PKG_DTL/High/${encodeURI(JSON.stringify({ sName: param.SessionName, Name: param.Name }))}`,
    );
  }

  return [methods, ActionColumn];
}

export default _default;
